==> touhoulittlemaid-fabric-1.20.1-0.1.7.2-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/datagen/LootTableGenerator.java <==
package com.github.tartaricacid.touhoulittlemaid.datagen;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitEntities;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.SimpleFabricLootTableProvider;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidConstants;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidVariant;
import net.minecraft.class_109;
import net.minecraft.class_141;
import net.minecraft.class_149;
import net.minecraft.class_159;
import net.minecraft.class_173;
import net.minecraft.class_1802;
import net.minecraft.class_2487;
import net.minecraft.class_2960;
import net.minecraft.class_3612;
import net.minecraft.class_44;
import net.minecraft.class_52;
import net.minecraft.class_55;
import net.minecraft.class_5662;
import net.minecraft.class_73;
import net.minecraft.class_77;
import org.jetbrains.annotations.NotNull;

import java.util.function.BiConsumer;

public class LootTableGenerator {
    public static final class_2960 ADVANCEMENT_POWER_POINT = getLootTableKey("advancement/power_point");
    public static final class_2960 CAKE = getLootTableKey("advancement/cake");

    public static final class_2960 CHEST_POWER_POINT = getLootTableKey("chest/power_point");
    public static final class_2960 FISHING_POWER_POINT = getLootTableKey("fishing/power_point");

    public static final class_2960 SHRINE_LESS = getLootTableKey("chest/shrine_less");
    public static final class_2960 SHRINE_MORE = getLootTableKey("chest/shrine_more");

    public static final class_2960 SPAWN_BONUS = getLootTableKey("chest/spawn_bonus");
    public static final class_2960 NORMAL_BACKPACK = getLootTableKey("chest/normal_backpack");
    public static final class_2960 FURNACE_OR_CRAFTING_TABLE_BACKPACK = getLootTableKey("chest/furnace_or_crafting_table_backpack");
    public static final class_2960 TANK_BACKPACK = getLootTableKey("chest/tank_backpack");
    public static final class_2960 ENDER_CHEST_BACKPACK = getLootTableKey("chest/ender_chest_backpack");

    public static final class_2960 NORMAL_BAUBLE = getLootTableKey("chest/normal_bauble");
    public static final class_2960 RARE_BAUBLE = getLootTableKey("chest/rare_bauble");
    public static final class_2960 VERY_RARE_BAUBLE = getLootTableKey("chest/very_rare_bauble");

    public static final class_2960 STRUCTURE_SPAWN_MAID_GIFT = getLootTableKey("chest/structure_spawn_maid_gift");
    public static final class_2960 MAID_BURIED_TREASURE = getLootTableKey("chest/maid_buried_treasure");

    public static class_2960 getLootTableKey(String name) {
        return new class_2960(TouhouLittleMaid.MOD_ID, name);
    }

    public static class ChestLootTables extends SimpleFabricLootTableProvider {
        public ChestLootTables(FabricDataOutput output) {
            super(output, class_173.field_1179);
        }

        @Override
        public void method_10399(BiConsumer<class_2960, class_52.class_53> consumer) {
            consumer.accept(CHEST_POWER_POINT, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.POWER_POINT)
                            .method_438(class_141.method_621(class_5662.method_32462(1, 2))))
                    .method_351(class_73.method_401().method_437(2))));

            consumer.accept(FISHING_POWER_POINT, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.POWER_POINT))
                    .method_351(class_73.method_401().method_437(9))));

            consumer.accept(SHRINE_LESS, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.SHRINE))
                    .method_351(class_73.method_401().method_437(9))));

            consumer.accept(SHRINE_MORE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.SHRINE))
                    .method_351(class_73.method_401().method_437(2))));

            consumer.accept(SPAWN_BONUS, class_52.method_324()
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.MAID_BACKPACK_SMALL).method_437(3))
                            .method_351(class_77.method_411(InitItems.MAID_BACKPACK_MIDDLE).method_437(9))
                            .method_351(class_77.method_411(InitItems.MAID_BACKPACK_BIG).method_437(4)))
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.POWER_POINT)
                                    .method_438(class_141.method_621(class_5662.method_32462(3, 9))))
                    ));

            consumer.accept(NORMAL_BACKPACK, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.MAID_BACKPACK_SMALL).method_437(3))
                    .method_351(class_77.method_411(InitItems.MAID_BACKPACK_MIDDLE).method_437(9))
                    .method_351(class_77.method_411(InitItems.MAID_BACKPACK_BIG).method_437(4))
                    .method_351(class_73.method_401().method_437(50))));

            consumer.accept(FURNACE_OR_CRAFTING_TABLE_BACKPACK, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.FURNACE_BACKPACK))
                    .method_351(class_77.method_411(InitItems.CRAFTING_TABLE_BACKPACK))
                    .method_351(class_73.method_401().method_437(8))));

            var tank1 = class_77.method_411(InitItems.TANK_BACKPACK).method_438(class_159.method_677(getLavaFluidStackTag(9)));
            var tank2 = class_77.method_411(InitItems.TANK_BACKPACK).method_438(class_159.method_677(getLavaFluidStackTag(4)));
            var tank3 = class_77.method_411(InitItems.TANK_BACKPACK).method_438(class_159.method_677(getLavaFluidStackTag(3)));

            consumer.accept(TANK_BACKPACK, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(tank1).method_351(tank2).method_351(tank3)
                    .method_351(class_73.method_401().method_437(12))));

            consumer.accept(ENDER_CHEST_BACKPACK, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.ENDER_CHEST_BACKPACK).method_437(1))
                    .method_351(class_73.method_401().method_437(4))));

            consumer.accept(NORMAL_BAUBLE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_5662.method_32462(1, 3))
                    // 有附魔的饰品
                    .method_351(class_77.method_411(InitItems.EXPLOSION_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.FIRE_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.PROJECTILE_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.MAGIC_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.FALL_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.DROWN_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    // 没有附魔的饰品
                    .method_351(class_77.method_411(InitItems.EXPLOSION_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.FIRE_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.PROJECTILE_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.MAGIC_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.FALL_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.DROWN_PROTECT_BAUBLE).method_437(4))
                    // 其他
                    .method_351(class_73.method_401().method_437(90))));

            consumer.accept(RARE_BAUBLE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_5662.method_32462(1, 2))
                    .method_351(class_77.method_411(InitItems.NIMBLE_FABRIC).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.NIMBLE_FABRIC))
                    .method_351(class_77.method_411(InitItems.ITEM_MAGNET_BAUBLE))
                    .method_351(class_73.method_401().method_437(6))));

            consumer.accept(VERY_RARE_BAUBLE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.ULTRAMARINE_ORB_ELIXIR).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.ULTRAMARINE_ORB_ELIXIR).method_437(2))
                    .method_351(class_73.method_401().method_437(4))));

            var setDamage = class_149.method_633(class_5662.method_32462(0.06f, 0.1f));
            consumer.accept(STRUCTURE_SPAWN_MAID_GIFT, class_52.method_324()
                    .method_336(class_55.method_347()
                            .method_352(class_5662.method_32462(1, 2))
                            .method_351(class_77.method_411(class_1802.field_17534)))
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.CAMERA).method_438(setDamage))));

            consumer.accept(MAID_BURIED_TREASURE, class_52.method_324()
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.SMART_SLAB_EMPTY))
                            .method_351(class_73.method_401().method_437(4)))
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.SHRINE))
                            .method_351(class_73.method_401())));
        }

        @NotNull
        private class_2487 getLavaFluidStackTag(int count) {
            class_2487 tankTag = new class_2487();
            FluidVariant fluidStack = FluidVariant.of(class_3612.field_15908);
            long amount = count * FluidConstants.BUCKET;
            class_2487 variantTag = new class_2487();
            variantTag.method_10566("variant", fluidStack.toNbt());
            variantTag.method_10544("amount", amount);
            tankTag.method_10566("Tanks", variantTag);
            return tankTag;
        }
    }

    public static class AdvancementLootTables extends SimpleFabricLootTableProvider {
        public AdvancementLootTables(FabricDataOutput output) {
            super(output, class_173.field_1174);
        }

        @Override
        public void method_10399(BiConsumer<class_2960, class_52.class_53> consumer) {
            consumer.accept(ADVANCEMENT_POWER_POINT, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(5))
                    .method_351(class_77.method_411(InitItems.POWER_POINT))));

            consumer.accept(CAKE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(class_1802.field_17534))));
        }
    }

    public static class EntityLootTables extends SimpleFabricLootTableProvider {
        public EntityLootTables(FabricDataOutput output) {
            super(output, class_173.field_1173);
        }

        @Override
        public void method_10399(BiConsumer<class_2960, class_52.class_53> consumer) {
            consumer.accept(InitEntities.BOX.method_16351(), class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(class_1802.field_8407))));
        }
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.4.0-forge1.4.5-sources.jar: com/github/tartaricacid/touhoulittlemaid/datagen/LootTableGenerator.java <==
package com.github.tartaricacid.touhoulittlemaid.datagen;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.init.InitEntities;
import com.github.tartaricacid.touhoulittlemaid.init.InitItems;
import com.github.tartaricacid.touhoulittlemaid.loot.RandomBoardStateFunction;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.SimpleFabricLootTableProvider;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidConstants;
import net.fabricmc.fabric.api.transfer.v1.fluid.FluidVariant;
import net.minecraft.class_109;
import net.minecraft.class_141;
import net.minecraft.class_149;
import net.minecraft.class_159;
import net.minecraft.class_173;
import net.minecraft.class_1802;
import net.minecraft.class_2487;
import net.minecraft.class_2960;
import net.minecraft.class_3612;
import net.minecraft.class_44;
import net.minecraft.class_52;
import net.minecraft.class_55;
import net.minecraft.class_5662;
import net.minecraft.class_73;
import net.minecraft.class_77;
import org.jetbrains.annotations.NotNull;

import java.util.function.BiConsumer;

public class LootTableGenerator {
    public static final class_2960 ADVANCEMENT_POWER_POINT = getLootTableKey("advancement/power_point");
    public static final class_2960 CAKE = getLootTableKey("advancement/cake");

    public static final class_2960 CHEST_POWER_POINT = getLootTableKey("chest/power_point");
    public static final class_2960 FISHING_POWER_POINT = getLootTableKey("fishing/power_point");

    public static final class_2960 SHRINE_LESS = getLootTableKey("chest/shrine_less");
    public static final class_2960 SHRINE_MORE = getLootTableKey("chest/shrine_more");

    public static final class_2960 SPAWN_BONUS = getLootTableKey("chest/spawn_bonus");
    public static final class_2960 NORMAL_BACKPACK = getLootTableKey("chest/normal_backpack");
    public static final class_2960 FURNACE_OR_CRAFTING_TABLE_BACKPACK = getLootTableKey("chest/furnace_or_crafting_table_backpack");
    public static final class_2960 TANK_BACKPACK = getLootTableKey("chest/tank_backpack");
    public static final class_2960 ENDER_CHEST_BACKPACK = getLootTableKey("chest/ender_chest_backpack");

    public static final class_2960 NORMAL_BAUBLE = getLootTableKey("chest/normal_bauble");
    public static final class_2960 RARE_BAUBLE = getLootTableKey("chest/rare_bauble");
    public static final class_2960 VERY_RARE_BAUBLE = getLootTableKey("chest/very_rare_bauble");

    public static final class_2960 STRUCTURE_SPAWN_MAID_GIFT = getLootTableKey("chest/structure_spawn_maid_gift");
    public static final class_2960 MAID_BURIED_TREASURE = getLootTableKey("chest/maid_buried_treasure");

    public static final class_2960 RANDOM_BOARD_STATE = getLootTableKey("chest/random_board_state");

    public static class_2960 getLootTableKey(String name) {
        return new class_2960(TouhouLittleMaid.MOD_ID, name);
    }

    public static class ChestLootTables extends SimpleFabricLootTableProvider {
        public ChestLootTables(FabricDataOutput output) {
            super(output, class_173.field_1179);
        }

        @Override
        public void method_10399(BiConsumer<class_2960, class_52.class_53> consumer) {
            consumer.accept(CHEST_POWER_POINT, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.POWER_POINT)
                            .method_438(class_141.method_621(class_5662.method_32462(1, 2))))
                    .method_351(class_73.method_401().method_437(2))));

            consumer.accept(FISHING_POWER_POINT, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.POWER_POINT))
                    .method_351(class_73.method_401().method_437(9))));

            consumer.accept(SHRINE_LESS, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.SHRINE))
                    .method_351(class_73.method_401().method_437(9))));

            consumer.accept(SHRINE_MORE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.SHRINE))
                    .method_351(class_73.method_401().method_437(2))));

            consumer.accept(SPAWN_BONUS, class_52.method_324()
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.MAID_BACKPACK_SMALL).method_437(3))
                            .method_351(class_77.method_411(InitItems.MAID_BACKPACK_MIDDLE).method_437(9))
                            .method_351(class_77.method_411(InitItems.MAID_BACKPACK_BIG).method_437(4)))
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.POWER_POINT)
                                    .method_438(class_141.method_621(class_5662.method_32462(3, 9))))
                    ));

            consumer.accept(NORMAL_BACKPACK, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.MAID_BACKPACK_SMALL).method_437(3))
                    .method_351(class_77.method_411(InitItems.MAID_BACKPACK_MIDDLE).method_437(9))
                    .method_351(class_77.method_411(InitItems.MAID_BACKPACK_BIG).method_437(4))
                    .method_351(class_73.method_401().method_437(50))));

            consumer.accept(FURNACE_OR_CRAFTING_TABLE_BACKPACK, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.FURNACE_BACKPACK))
                    .method_351(class_77.method_411(InitItems.CRAFTING_TABLE_BACKPACK))
                    .method_351(class_73.method_401().method_437(8))));

            var tank1 = class_77.method_411(InitItems.TANK_BACKPACK).method_438(class_159.method_677(getLavaFluidStackTag(9)));
            var tank2 = class_77.method_411(InitItems.TANK_BACKPACK).method_438(class_159.method_677(getLavaFluidStackTag(4)));
            var tank3 = class_77.method_411(InitItems.TANK_BACKPACK).method_438(class_159.method_677(getLavaFluidStackTag(3)));

            consumer.accept(TANK_BACKPACK, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(tank1).method_351(tank2).method_351(tank3)
                    .method_351(class_73.method_401().method_437(12))));

            consumer.accept(ENDER_CHEST_BACKPACK, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.ENDER_CHEST_BACKPACK).method_437(1))
                    .method_351(class_73.method_401().method_437(4))));

            consumer.accept(NORMAL_BAUBLE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_5662.method_32462(1, 3))
                    // 有附魔的饰品
                    .method_351(class_77.method_411(InitItems.EXPLOSION_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.FIRE_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.PROJECTILE_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.MAGIC_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.FALL_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.DROWN_PROTECT_BAUBLE).method_438(class_109.method_489()))
                    // 没有附魔的饰品
                    .method_351(class_77.method_411(InitItems.EXPLOSION_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.FIRE_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.PROJECTILE_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.MAGIC_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.FALL_PROTECT_BAUBLE).method_437(4))
                    .method_351(class_77.method_411(InitItems.DROWN_PROTECT_BAUBLE).method_437(4))
                    // 其他
                    .method_351(class_73.method_401().method_437(90))));

            consumer.accept(RARE_BAUBLE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_5662.method_32462(1, 2))
                    .method_351(class_77.method_411(InitItems.NIMBLE_FABRIC).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.NIMBLE_FABRIC))
                    .method_351(class_77.method_411(InitItems.ITEM_MAGNET_BAUBLE))
                    .method_351(class_73.method_401().method_437(6))));

            consumer.accept(VERY_RARE_BAUBLE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(InitItems.ULTRAMARINE_ORB_ELIXIR).method_438(class_109.method_489()))
                    .method_351(class_77.method_411(InitItems.ULTRAMARINE_ORB_ELIXIR).method_437(2))
                    .method_351(class_73.method_401().method_437(4))));

            var setDamage = class_149.method_633(class_5662.method_32462(0.06f, 0.1f));
            consumer.accept(STRUCTURE_SPAWN_MAID_GIFT, class_52.method_324()
                    .method_336(class_55.method_347()
                            .method_352(class_5662.method_32462(1, 2))
                            .method_351(class_77.method_411(class_1802.field_17534)))
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.CAMERA).method_438(setDamage))));

            consumer.accept(MAID_BURIED_TREASURE, class_52.method_324()
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.SMART_SLAB_EMPTY))
                            .method_351(class_73.method_401().method_437(4)))
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.SHRINE))
                            .method_351(class_73.method_401())));

            var library = RandomBoardStateFunction.create().addTag("library");
            consumer.accept(RANDOM_BOARD_STATE, class_52.method_324()
                    .method_336(class_55.method_347()
                            .method_352(class_44.method_32448(1))
                            .method_351(class_77.method_411(InitItems.GOMOKU_BOARD_STATE).method_438(library))
                            .method_351(class_77.method_411(InitItems.CCHESS_BOARD_STATE).method_438(library))
                            .method_351(class_77.method_411(InitItems.WCHESS_BOARD_STATE).method_438(library))));
        }

        @NotNull
        private class_2487 getLavaFluidStackTag(int count) {
            class_2487 tankTag = new class_2487();
            FluidVariant fluidStack = FluidVariant.of(class_3612.field_15908);
            long amount = count * FluidConstants.BUCKET;
            class_2487 variantTag = new class_2487();
            variantTag.method_10566("variant", fluidStack.toNbt());
            variantTag.method_10544("amount", amount);
            tankTag.method_10566("Tanks", variantTag);
            return tankTag;
        }
    }

    public static class AdvancementLootTables extends SimpleFabricLootTableProvider {
        public AdvancementLootTables(FabricDataOutput output) {
            super(output, class_173.field_1174);
        }

        @Override
        public void method_10399(BiConsumer<class_2960, class_52.class_53> consumer) {
            consumer.accept(ADVANCEMENT_POWER_POINT, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(5))
                    .method_351(class_77.method_411(InitItems.POWER_POINT))));

            consumer.accept(CAKE, class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(class_1802.field_17534))));
        }
    }

    public static class EntityLootTables extends SimpleFabricLootTableProvider {
        public EntityLootTables(FabricDataOutput output) {
            super(output, class_173.field_1173);
        }

        @Override
        public void method_10399(BiConsumer<class_2960, class_52.class_53> consumer) {
            consumer.accept(InitEntities.BOX.method_16351(), class_52.method_324().method_336(class_55.method_347()
                    .method_352(class_44.method_32448(1))
                    .method_351(class_77.method_411(class_1802.field_8407))));
        }
    }
}
